@@ -38,6 +38,7 @@ import locale
 import email.utils as eut
 import pynotify
 import dbus
+import location
 
 class account():
 
@@ -49,6 +50,10 @@ class account():
     INACTIVE = 2
     status = ""
     avatar_size = 60
+    lat=None
+    long = None
+    location = True
+    stopLocation=False
     _MCE_SERVICE = 'com.nokia.mce'
     _MCE_REQUEST_PATH = '/com/nokia/mce/request'
     _MCE_REQUEST_IF = 'com.nokia.mce.request'
@@ -90,13 +95,40 @@ class account():
         self.connect()
         self.dmnotify = pynotify.Notification("Witter","You have new DMs")
         self.dmnotify.add_action("clicked","Show DMs", self.dm_callback)
+        #TODO move this and check if the call can be put on background thread from main loop
+        #self.updateLocation()
+        
+    def updateLocation(self):    
+        #start up location tracking
+        loop = gobject.MainLoop()
+        self.control = location.GPSDControl.get_default()
+        device = location.GPSDevice()
+        self.control.set_properties(preferred_method=location.METHOD_ACWP,
+                       preferred_interval=location.INTERVAL_DEFAULT)
+ 
+        self.control.connect("error-verbose", self.on_error, loop)
+        device.connect("changed", self.on_changed, self.control)
+        self.control.connect("gpsd-stopped", self.on_stop, loop)
+ 
+        gobject.idle_add(self.start_location, self.control)
+ 
+        loop.run()
 
+    def stopLocation(self):
+        print "stop location tracking"
+        self.control.stop()
+
+    def startLocation(self):
+        print "start location tracking"
+        self.control.start()
+        
     def connect(self):
         if self.accountdata.password:
             print "Establishing api for " + self.accountdata.servicename + " using basic auth"
             self.api = twitter.Api(username=self.accountdata.username, password=self.accountdata.password)
             self.api.SetBaseUrl(self.accountdata.baseUrl)
             self.api.SetBaseSearchUrl(self.accountdata.searchUrl)
+            
         if (self.accountdata.access_token != None):
             print "Establishing api for " + self.accountdata.servicename + " using oauth"
             self.api = oauthtwitter.OAuthApi(self.CONSUMER_KEY, self.CONSUMER_SECRET, self.accountdata.access_token)
@@ -107,6 +139,23 @@ class account():
             print "Connection working ok"
             return True
 
+    def setProfileInfo(self):
+        user = self.api.GetUser(self.accountdata.username)
+        self.controller.ui.profileTweetsLabel.set_text("TweetCount: " +str(user.GetStatusesCount()))
+        self.controller.ui.profileFollowerCount.set_text("Followers: "+str(user.GetFollowersCount()))
+        self.controller.ui.profileFollowingCount.set_text("Following: " +str(user.GetFriendsCount()))
+        self.controller.ui.accountNameLabel.set_text(self.accountdata.username)
+        self.controller.ui.profileLastTweet.set_text(user.GetStatus().GetText())
+        if (user.GetStatus().GetPlace() != None):
+            self.controller.ui.profileLocation.set_text(user.GetStatus().GetPlace().name)
+        else:
+            self.controller.ui.profileLocation.set_text(user.GetLocation())
+            
+        avatar, loaded = self.retrieve_avatar(user.GetProfileImageUrl(), str(user.id)+".jpg")   
+        avatar = avatar.scale_simple(90, 90, gtk.gdk.INTERP_BILINEAR)
+        #self.controller.ui.profileImage.set_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + str(user.id)+".jpg")
+        self.controller.ui.profileImage.set_from_pixbuf(avatar)  
+            
     def getAccountData(self):
         return self.accountdata
 
@@ -245,10 +294,15 @@ class account():
                      source = self.getSourceAppname(x.source)
                      text = self.escapeText(x.text)
                      text = self.controller.expandBitlyUrls(text)
+                     if (x.GetPlace() !=None):
+                         place = x.GetPlace().name
+                     else:
+                         place=None
+                     
                      pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
                      created_at = self.parse_time(x.created_at)
                      formatted_ts = self.format_timestamp(created_at)
-                     formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
+                     formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to, loc=place)
                      longid= long(x.id)
                      self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", longid, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                      
@@ -281,12 +335,7 @@ class account():
             if (auto == 0):
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog("Network error occured. Please try again")
-        except httplib.sslerror:
-            print "Network error - SslError"
-            if (auto == 0):
-                note = osso.SystemNote(self.osso_c)
-                note.system_note_dialog("Network error occured. Please try again")
-
+        
 
     def getMentions(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
@@ -389,12 +438,7 @@ class account():
             if (auto == 0):
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog("Network error occured. Please try again")
-        except httplib.sslerror:
-            print "Network error - SslError"
-            if (auto == 0):
-                note = osso.SystemNote(self.osso_c)
-                note.system_note_dialog("Network error occured. Please try again")
-                
+                 
     def getDMs(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
             if (self.connect() != True):
@@ -488,12 +532,7 @@ class account():
             if (auto == 0):
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog("Network error occured. Please try again")
-        except httplib.sslerror:
-            print "Network error - SslError"
-            if (auto == 0):
-                note = osso.SystemNote(self.osso_c)
-                note.system_note_dialog("Network error occured. Please try again")
-                
+                 
     def getFriends(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
             if (self.connect() != True):
@@ -528,7 +567,8 @@ class account():
                 if (receive_count > 0):
                     note = osso.SystemNote(self.osso_c)
                     result = note.system_note_infoprint(str(receive_count) + " Friends Received")
-
+                #update friend/follower counts etc
+                self.setProfileInfo()
         except IOError, e:
             print "error"
             msg = 'Error retrieving friends '
@@ -552,12 +592,7 @@ class account():
             if (auto == 0):
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog("Network error occured. Please try again")
-        except httplib.sslerror:
-            print "Network error - SslError"
-            if (auto == 0):
-                note = osso.SystemNote(self.osso_c)
-                note.system_note_dialog("Network error occured. Please try again")
-                
+                 
     def getPublic(self, auto=0, older=False, get_count=20, * args):
         if (self.api == None):
             if (self.connect() != True):
@@ -646,12 +681,7 @@ class account():
             if (auto == 0):
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog("Network error occured. Please try again")
-        except httplib.sslerror:
-            print "Network error - SslError"
-            if (auto == 0):
-                note = osso.SystemNote(self.osso_c)
-                note.system_note_dialog("Network error occured. Please try again")
-
+       
     def getUserHistory(self, friend="", auto=0, older=False, get_count=20, * args):
         if (self.api == None):
             if (self.connect() != True):
@@ -874,18 +904,40 @@ class account():
         #see if we have just an empty string (eg eroneous button press)
         if (tweet == ""):
             return False
-
+        #if (self.controller.location):
+        #    self.updateLocation()
         try:
 
             if (reply_to_name != None):
                 if (re.search(reply_to_name, tweet)):
                     #this is a reply
-                    status = self.api.PostUpdate(tweet, reply_to_id)
+                    print "reply to " + reply_to_name
+                    if (self.controller.location):
+                        print "Tweeting with location info"
+                        print str(self.lat)
+                        print str(self.long)
+                        status = self.api.PostUpdate(tweet, reply_to_id, lat=self.lat, long=self.long)
+                    else:
+                        status = self.api.PostUpdate(tweet, reply_to_id)
+                else:
+                    if (self.controller.location):
+                        print "tweeting with location info"
+                        print str(self.lat)
+                        print str(self.long)
+                        
+                        status = self.api.PostUpdate(tweet, lat=self.lat, long=self.long)
+                    else:
+                        status = self.api.PostUpdate(tweet)
+            else:
+                if (self.controller.location):
+                    print "Tweeting with location info"
+                    print str(lat)
+                    print str(long)
+                    status = self.api.PostUpdate(tweet, lat=self.lat, long=self.long)
                 else:
                     status = self.api.PostUpdate(tweet)
-            else:
-                status = self.api.PostUpdate(tweet)
-
+            #update tweet count
+            self.setProfileInfo()
             return True
         except IOError, e:
             msg = 'Error posting tweet '
@@ -911,12 +963,6 @@ class account():
                 note = osso.SystemNote(self.osso_c)
                 note.system_note_dialog("Network error occured. Please try again")
             return False
-        except httplib.sslerror:
-            print "Network error - SslError"
-            if (auto == 0):
-                note = osso.SystemNote(self.osso_c)
-                note.system_note_dialog("Network error occured. Please try again")
-            return False
 
     def FavouriteTweet(self, widget, id, *args):
         
@@ -976,7 +1022,8 @@ class account():
                     formatted_ts = self.format_timestamp(created_at)
                     formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
                     self.tweetstore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", long(x.id), "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
-                 
+                #update follower count
+                self.setProfileInfo()
         except IOError, e:
             print "error"
             msg = 'Error following ' + name + ' '
@@ -1005,6 +1052,8 @@ class account():
                 data = self.api.DestroyFriendship(name)
                 note = osso.SystemNote(self.osso_c)
                 result = note.system_note_infoprint("No longer following " + name)
+                #update following count
+                self.setProfileInfo()
         except IOError, e:
             print "error"
             msg = 'Error unfollowing ' + name + ' '
@@ -1158,7 +1207,7 @@ class account():
             return pixbuf, False
         return pixbuf, True
 
-    def format_tweet(self, user, tweet, time, source, reply_to):
+    def format_tweet(self, user, tweet, time, source, reply_to, loc=None):
         tweet = tweet.replace("&amp;", "&")
         tweet = gobject.markup_escape_text(tweet)
         if (source != None):
@@ -1172,7 +1221,7 @@ class account():
                     word = " <span foreground = \"#0075b5\">" + word[0:len(word)-1] + "</span>" + word[len(word)-1:len(word)]
                 else:
                     word = " <span foreground = \"#0075b5\">" + word + "</span>"
-            if (word.startswith("http:")):
+            if (word.startswith("http:") | word.startswith("www")):
                 word = "<span foreground=\"#0075b5\">" + word + "</span>"
             if (word.startswith("witter") | word.startswith("Witter") | word.startswith("#witter") | word.startswith("#Witter")):
                 word = "<span foreground=\"yellow\">" + word + "</span>"
@@ -1184,7 +1233,10 @@ class account():
         if (source != None):
             if (source.startswith("Witter")):
                 source = "<span foreground=\"yellow\">" + source + "</span>"
-            line = line + "\n<span weight='light' size='x-small'>" + time + " from " + source + "</span>"
+            if loc:
+                line = line + "\n<span weight='light' size='x-small'>" + time + " from " + source + " in " + loc + "</span>"
+            else:
+                line = line + "\n<span weight='light' size='x-small'>" + time + " from " + source + "</span>"
         else:
             line = line + "\n<span weight='light' size='x-small'>" + time + "</span>"
         return line
@@ -1307,6 +1359,29 @@ class account():
             item = store.iter_next(item)
         return False    
         
+    def on_error(self,control, error, data):
+        print "location error: %d... quitting" % error
+        data.quit()
+ 
+    def on_changed(self,device, data):
+        if self.stopLocation:
+            #stoppping location tracking
+            data.stop()
+        if not device:
+            return
+        if device.fix:
+            if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
+                print "lat = %f, long = %f" % device.fix[4:6]
+                self.lat, self.long = device.fix[4:6]
+                #data.stop()
+    
+    def on_stop(self,control, data):
+        print "quitting"
+        data.quit()
+ 
+    def start_location(self,data):
+        data.start()
+        return False
+    
     
-        
         
\ No newline at end of file
