@@ -141,6 +141,7 @@ class Witter():
         self.selectedUser = ""
         self.theme = "default"
         self.gestures = True
+        self.location = True
         self.emailnotifications = True
         self.orientation = 'Landscape'
         #
@@ -201,7 +202,7 @@ class Witter():
             mymode =FremantleRotation.AUTOMATIC
         
         self.rotation = FremantleRotation("Witter", self.ui.window, mode=mymode)
-
+        self.activeAccount.setProfileInfo()
 
     def quit(self, *args):
         #this is our end method called when window is closed
@@ -429,6 +430,19 @@ class Witter():
                 print "no text colour setting"
             except ConfigParser.NoOptionError:
                 print "missing option in config"
+            try:
+                loc = config.get("General","location")
+                if (loc == "True"):
+                    self.location = True
+                    print "tweet with location enabled"
+                else:
+                    self.location = False
+                    print "tweet with location disabled"
+            except ConfigParser.NoSectionError:
+                print "no location setting"
+            except ConfigParser.NoOptionError:
+                print "missing location option in config"
+                   
             try:
                 serviceType = config.get("Service", "type")
                 if (serviceType == "twitter"):
@@ -559,6 +573,8 @@ class Witter():
                 f.write("notifications_enabled = True\n")
             else:
                 f.write("notifications_enabled = False\n")
+            f.write("[General]\n")
+            f.write("location = " + str(self.location) +"\n")
             f.write("[refresh_interval]\n")
             f.write("timeline = " + str(self.timelineRefreshInterval) + "\n")
             f.write("mentions = " + str(self.mentionsRefreshInterval) + "\n")
@@ -841,7 +857,8 @@ class Witter():
 
 
     def end_refresh_threads(self):
-	    #end all the refresh threads
+	    self.activeAccount.stopLocation()
+        #end all the refresh threads
 	    if (self.refreshtask != None):
 		self.refreshtask.stop()
 	    if (self.dmrefresh != None):
@@ -853,27 +870,33 @@ class Witter():
 	    if (self.searchrefresh != None):
 		self.searchrefresh.stop()
 
-
     def start_refresh_threads(self):
 	    #we store the refresh interval in minutes, but pass it through as a value in seconds
 	    #this method launches a thread for each of the views we want to have auto-refreshed
-	    if (self.timelineRefreshInterval != 0):
+        if (self.timelineRefreshInterval != 0):
 		    self.refreshtask = witter.RefreshTask(self.getTweetsWrapper, 0 , None)
 		    self.refreshtask.start(self.timelineRefreshInterval * 60, self)
-	    if (self.DMsRefreshInterval != 0):
+        if (self.DMsRefreshInterval != 0):
 		    self.dmrefresh = witter.RefreshTask(self.getDMsWrapper, 0, None)
 		    self.dmrefresh.start(self.DMsRefreshInterval * 60, self)
-	    if (self.mentionsRefreshInterval != 0):
+        if (self.mentionsRefreshInterval != 0):
 		    self.mentionrefresh = witter.RefreshTask(self.getMentionsWrapper, 0, None)
 		    self.mentionrefresh.start(self.mentionsRefreshInterval * 60, self)
-	    if (self.publicRefreshInterval != 0) :
+        if (self.publicRefreshInterval != 0) :
 		    self.publicrefresh = witter.RefreshTask(self.getPublicWrapper, 0, None)
 		    self.publicrefresh.start(self.publicRefreshInterval * 60, self)
-	    if (self.searchRefreshInterval != 0) :
+        if (self.searchRefreshInterval != 0) :
 		    self.searchrefresh = witter.RefreshTask(self.getSearchWrapper, 0, None)
 		    self.searchrefresh.start(self.searchRefreshInterval * 60, self)
-	    print "end refresh setup"
+            
+        self.locationUpdateThread = witter.RefreshTask(self.startLocation, 0, None)
+        self.locationUpdateThread.refresh()
+        print "end refresh setup"
 
+    def startLocation(self, get_older=False, more=0, autoval=None):
+        self.activeAccount.updateLocation()
+        
+        
     def getTweetsWrapper(self, get_older=False, more=0, autoval=None):
         self.ui.showBusy(1)
         self.establish_connection()
@@ -1127,6 +1150,7 @@ class Witter():
             self.ui.icon_size = 30
             self.ui.load_theme_icons()
             self.ui.define_ui_buttons()
+            self.ui.current_orientation = 'portrait'
             
          if ((orientation == 'landscape') & (self.ui.orientation != 'Portrait')):
             print "switching to landscape"
@@ -1136,6 +1160,7 @@ class Witter():
             self.ui.load_theme_icons()
             self.ui.define_ui_buttons()
             self.ui.hide_portrait_keyboard()
+            self.ui.current_orientation = 'landscape'
          print "refresh current view"
          curView = self.ui.getCurrentView()  
          if (curView == self.ui.TIMELINE_VIEW):
